==> skrooge_0.7.3.2.orig.tar.gz: skrooge-0.7.3.2/skgapplets/highlightedoperation/highlightedoperationskroogoid.cpp <==
/***************************************************************************
 *   Copyright (C) 2010 by SIDDHARTH SHARMA siddharth.kde@gmail.com        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
/** @file
* This file is Plasma Applet for Highlighted Operation Skroogoid
*
* @author Siddharth SHARMA
*/

#include "highlightedoperationskroogoid.h"

#include "skgdocumentbank.h"
#include "skgtraces.h"
#include "skgservices.h"
#include "skgoperationobject.h"
#include "skgmainpanel.h"

#include <QGraphicsLinearLayout>

HighlightedOperationSkroogoid::HighlightedOperationSkroogoid( QObject *parent, const QVariantList &args )
        : Plasma::PopupApplet( parent, args )
{

    setAspectRatioMode(Plasma::IgnoreAspectRatio);
    resize(300,300);
    gl_layout=new QGraphicsLinearLayout();
    setLayout(gl_layout);

    displayLabel=new Plasma::Label();
    QString html;
    SKGMainPanel* panel=SKGMainPanel::getMainPanel();
    SKGDocumentBank* doc= dynamic_cast<SKGDocumentBank*> ( panel->getDocument() );
    SKGServices::SKGUnitInfo primary= doc->getPrimaryUnit();
    SKGObjectBase::SKGListSKGObjectBase objs;
    SKGError err=SKGObjectBase::getObjects ( panel->getDocument(), "v_operation_display", "t_bookmarked='Y' ORDER BY d_date", objs );
    if (doc)
    {
        if ( err.isSucceeded() )
        {
            html="<html><body>";
            int nb=objs.count();
            if ( nb )
            {
                for ( int i=0; i<nb; ++i )
                {
                    SKGOperationObject obj=objs.at ( i );
                    html+="<a href=\""+SKGServices::intToString ( obj.getID() ) +"\">"+SKGServices::stringToHtml ( obj.getDisplayName() ) +"</a><br>";
                }
            }
            else
            {
                html+=i18nc ("Message", "No operation highlighted<br>on the <a href=\"___\">\"Operations\"</a> page." );
            }
            html+="</body></html>";
            displayLabel->setText ( html );
            gl_layout->addItem(displayLabel);
        }
    }
}

HighlightedOperationSkroogoid::~HighlightedOperationSkroogoid()
{
}


#include "highlightedoperationskroogoid.moc"

==> skrooge_0.9.92.orig.tar.gz: skrooge-0.9.92/skgapplets/highlightedoperation/highlightedoperationskroogoid.cpp <==
/***************************************************************************
 *   Copyright (C) 2010 by SIDDHARTH SHARMA siddharth.kde@gmail.com        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
/** @file
* This file is Plasma Applet for Highlighted Operation Skroogoid
*
* @author Siddharth SHARMA
*/

#include "highlightedoperationskroogoid.h"

#include "skgdocumentbank.h"
#include "skgtraces.h"
#include "skgservices.h"
#include "skgoperationobject.h"
#include "skgmainpanel.h"

#include <QGraphicsLinearLayout>

HighlightedOperationSkroogoid::HighlightedOperationSkroogoid(QObject *parent, const QVariantList &args)
    : Plasma::PopupApplet(parent, args)
{

    setAspectRatioMode(Plasma::IgnoreAspectRatio);
    resize(300, 300);
    gl_layout = new QGraphicsLinearLayout();
    setLayout(gl_layout);

    displayLabel = new Plasma::Label();
    QString html;
    SKGMainPanel* panel = SKGMainPanel::getMainPanel();
    SKGDocumentBank* doc = qobject_cast<SKGDocumentBank*>(panel->getDocument());
    SKGServices::SKGUnitInfo primary = doc->getPrimaryUnit();
    SKGObjectBase::SKGListSKGObjectBase objs;
    SKGError err = panel->getDocument()->getObjects("v_operation_display", "t_bookmarked='Y' ORDER BY d_date", objs);
    if(doc) {
        if(!err) {
            html = "<html><body>";
            int nb = objs.count();
            if(nb) {
                for(int i = 0; i < nb; ++i) {
                    SKGOperationObject obj = objs.at(i);
                    html += "<a href=\"" % SKGServices::intToString(obj.getID()) % "\">" % SKGServices::stringToHtml(obj.getDisplayName()) % "</a><br>";
                }
            } else {
                html += i18nc("Message", "No operation highlighted<br>on the <a href=\"___\">\"Operations\"</a> page.");
            }
            html += "</body></html>";
            displayLabel->setText(html);
            gl_layout->addItem(displayLabel);
        }
    }
}

HighlightedOperationSkroogoid::~HighlightedOperationSkroogoid()
{
}


#include "highlightedoperationskroogoid.moc"
